@@ -30,7 +30,7 @@
 ;;;; Requirements
 
 (require 'ement)
-(require 'ement-taxy)
+(require 'ement-room-list)
 
 (require 'taxy)
 (require 'taxy-magit-section)
@@ -150,6 +150,7 @@
 
 ;; TODO: Pagination of results.
 
+;;;###autoload
 (cl-defun ement-directory (&key server session since (limit 100))
   "View the public room directory on SERVER with SESSION.
 Show up to LIMIT rooms.  Interactively, with prefix, prompt for
@@ -188,12 +189,18 @@ SINCE may be a next-batch token."
                                    (alist-get 'limit ement-directory-etc) limit)
                              (setq-local revert-buffer-function revert-function)
                              (when remaining
+                               ;; FIXME: The server seems to report all of the rooms on
+                               ;; the server as remaining even when searching for a
+                               ;; specific term like "emacs".
+                               ;; TODO: Display this in a more permanent place (like a
+                               ;; header or footer).
                                (message
                                 (substitute-command-keys
                                  "%s rooms remaining (use \\[ement-directory-next] to fetch more)")
                                 remaining)))))))
     (ement-message "Listing %s rooms on %s..." limit server)))
 
+;;;###autoload
 (cl-defun ement-directory-search (query &key server session since (limit 1000))
   "View public rooms on SERVER matching QUERY.
 QUERY is a string used to filter results."
@@ -307,8 +314,8 @@ contents.  To be called by `ement-directory-search'."
                          (apply #'make-taxy-magit-section
                                 :make #'make-fn
                                 :format-fn #'format-item
-                                ;; FIXME: Should we reuse `ement-taxy-level-indent' here?
-                                :level-indent ement-taxy-level-indent
+                                ;; FIXME: Should we reuse `ement-room-list-level-indent' here?
+                                :level-indent ement-room-list-level-indent
                                 ;; :visibility-fn #'visible-p
                                 ;; :heading-indent 2
                                 :item-indent 2
