@@ -739,6 +739,10 @@ USER is an `ement-user' struct."
 ;; These functions aren't expected to be called by code in other packages (but if that
 ;; were necessary, they could be renamed accordingly).
 
+(defun ement--room-space-p (room)
+  "Return non-nil if ROOM is a space."
+  (equal "m.space" (ement-room-type room)))
+
 (cl-defun ement--prism-color (string &key (contrast-with (face-background 'default nil 'default)))
   "Return a computed color for STRING.
 The color is adjusted to have sufficient contrast with the color
@@ -924,7 +928,7 @@ period, anywhere in the body."
     (when body
       (string-match-p (rx (or space bos) "@room" eow) body))))
 
-(cl-defun ement-complete-room (&key session predicate
+(cl-defun ement-complete-room (&key session (predicate #'identity)
                                     (prompt "Room: ") (suggest t))
   "Return a (room session) list selected from SESSION with completion.
 If SESSION is nil, select from rooms in all of `ement-sessions'.
@@ -941,6 +945,7 @@ suggested room."
                (name-to-room-session
                 (cl-loop for session in sessions
                          append (cl-loop for room in (ement-session-rooms session)
+                                         when (funcall predicate room)
                                          collect (cons (ement--format-room room 'topic)
                                                        (list room session)))))
                (names (mapcar #'car name-to-room-session))
@@ -1020,6 +1025,7 @@ DATA is an unsent message event's data alist."
                (replying-to-sender-name (ement--user-displayname-in ement-room replying-to-sender))
                (quote-string (format "> <%s> %s\n\n" replying-to-sender-name replying-to-body))
                (reply-body (alist-get "body" data nil nil #'string=))
+               (reply-formatted-body (alist-get "formatted_body" data nil nil #'string=))
                (reply-body-with-quote (concat quote-string reply-body))
                (reply-formatted-body-with-quote
                 (format "<mx-reply>
@@ -1036,7 +1042,7 @@ DATA is an unsent message event's data alist."
                         ;; might hope: there's `web-mode-html-entities' and `org-entities'.  See also
                         ;; <https://emacs.stackexchange.com/questions/8166/encode-non-html-characters-to-html-equivalent>.
                         (or replying-to-formatted-body replying-to-body)
-                        reply-body)))
+                        (or reply-formatted-body reply-body))))
     ;; NOTE: map-elt doesn't work with string keys, so we use `alist-get'.
     (setf (alist-get "body" data nil nil #'string=) reply-body-with-quote
           (alist-get "formatted_body" data nil nil #'string=) reply-formatted-body-with-quote
@@ -1132,18 +1138,24 @@ m.replace metadata)."
   "Return ROOM formatted with name, alias, ID, and optionally TOPIC.
 Suitable for use in completion, etc."
   (if topic
-      (format "\"%s\" <%s> (<%s>): \"%s\""
+      (format "%s%s(<%s>)%s"
               (or (ement-room-display-name room)
                   (setf (ement-room-display-name room)
                         (ement--room-display-name room)))
-              (ement-room-canonical-alias room)
+              (if (ement-room-canonical-alias room)
+                  (format " <%s> " (ement-room-canonical-alias room))
+                " ")
               (ement-room-id room)
-              (ement-room-topic room))
-    (format "\"%s\" <%s> (<%s>)"
+              (if (ement-room-topic room)
+                  (format ": \"%s\"" (ement-room-topic room))
+                ""))
+    (format "%s%s(<%s>)"
             (or (ement-room-display-name room)
                 (setf (ement-room-display-name room)
                       (ement--room-display-name room)))
-            (ement-room-canonical-alias room)
+            (if (ement-room-canonical-alias room)
+                (format " <%s> " (ement-room-canonical-alias room))
+              " ")
             (ement-room-id room))))
 
 (defun ement--members-alist (room)
@@ -1218,12 +1230,12 @@ IMAGE should be one as created by, e.g. `create-image'."
 (declare-function eieio-oref "eieio-core")
 (defun ement--room-at-point ()
   "Return room at point.
-Works in major-modes `ement-room-mode', `ement-room-list-mode',
-and `ement-taxy-mode'."
+Works in major-modes `ement-room-mode',
+`ement-tabulated-room-list-mode', and `ement-room-list-mode'."
   (pcase major-mode
     ('ement-room-mode (ement--format-room ement-room 'topic))
-    ('ement-room-list-mode (ement--format-room (tabulated-list-get-id) 'topic))
-    ('ement-taxy-mode
+    ('ement-tabulated-room-list-mode (ement--format-room (tabulated-list-get-id) 'topic))
+    ('ement-room-list-mode
      (cl-typecase (oref (magit-current-section) value)
        (taxy-magit-section nil)
        (t (pcase (oref (magit-current-section) value)
